@@ -26,11 +26,11 @@ Pg::Explain::StringAnonymizer - Class to anonymize sets of strings
 
 =head1 VERSION
 
-Version 1.01
+Version 1.02
 
 =cut
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 =head1 SYNOPSIS
 
@@ -157,7 +157,7 @@ sub anonymize_text {
     my $self = shift;
     my $text = shift;
     my $re   = $self->{ 'keys_re' };
-    $text =~ s{(?:\b|\s)($re)(?:\b|\s)}{ $self->{'strings'}->{$1} }mge;
+    $text =~ s{(\b|\s)($re)(\b|\s)}{ $1 . $self->{'strings'}->{$2} . $3 }mge;
     return $text;
 }
 
